/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: xextract.h                                                    *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : xextract.c header file                                   *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*
 */

/*
   Copyright (C) 1997-2021 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __XEXTRACT_H__
#define __XEXTRACT_H__

/****************************************************************************
                            F U N C T I O N S
****************************************************************************/
gboolean XMdcExtractNotBussy(GtkWidget *widget, gpointer data);
void XMdcExtractImages(void);
int  XMdcHandleEcatList(char *S,Uint32 **list,Uint32 max);
int  XMdcHandleNormList(char *s,Uint32 **inrs,Uint32 *it,Uint32 *bt,Uint32 max);
void XMdcGetImagesCallbackApply(GtkWidget *widget, gpointer data);
void XMdcGetImages(GtkWidget *widget, guint style);

#endif

